@@ -28,17 +28,17 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <tqobject.h>
 #include <tqpixmap.h>
 
-class KPopupMenu;
+class TDEPopupMenu;
 class KSystemTray;
 
 class TrayComponent : public TQObject
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
     TrayComponent(KSystemTray * parent, const char * name );
     virtual ~TrayComponent();
-    virtual void addMenuItems(KPopupMenu* menu) = 0;
+    virtual void addMenuItems(TDEPopupMenu* menu) = 0;
     KSystemTray * tray() const;;
     virtual TQStringList getToolTipText();
 signals:
